summaryrefslogtreecommitdiffstats
path: root/juk/k3bexporter.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'juk/k3bexporter.cpp')
-rw-r--r--juk/k3bexporter.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/juk/k3bexporter.cpp b/juk/k3bexporter.cpp
index a08ddcfe..d19021e6 100644
--- a/juk/k3bexporter.cpp
+++ b/juk/k3bexporter.cpp
@@ -23,8 +23,8 @@
#include <kiconloader.h>
#include <kapplication.h>
-#include <qcstring.h>
-#include <qmap.h>
+#include <tqcstring.h>
+#include <tqmap.h>
#include <dcopref.h>
#include <dcopclient.h>
@@ -50,8 +50,8 @@ class PlaylistAction : public KAction
{
public:
PlaylistAction(const char *name,
- const QString &userText,
- const QIconSet &pix,
+ const TQString &userText,
+ const TQIconSet &pix,
const char *slot,
const KShortcut &cut = 0) :
KAction(userText, pix, cut, 0 /* receiver */, 0 /* slot */, actions(), name),
@@ -59,13 +59,13 @@ class PlaylistAction : public KAction
{
}
- typedef QMap<const Playlist *, QObject *> PlaylistRecipientMap;
+ typedef TQMap<const Playlist *, TQObject *> PlaylistRecipientMap;
/**
* Defines a QObject to call (using the m_slot SLOT) when an action is
* emitted from a Playlist.
*/
- void addCallMapping(const Playlist *p, QObject *obj)
+ void addCallMapping(const Playlist *p, TQObject *obj)
{
m_playlistRecipient[p] = obj;
}
@@ -81,19 +81,19 @@ class PlaylistAction : public KAction
return;
// Make sure we're supposed to notify someone about this playlist.
- QObject *recipient = m_playlistRecipient[p];
+ TQObject *recipient = m_playlistRecipient[p];
if(!recipient)
return;
// Invoke the slot using some trickery.
- // XXX: Use the QMetaObject to do this in Qt 4.
- connect(this, SIGNAL(activated()), recipient, m_slot);
+ // XXX: Use the TQMetaObject to do this in Qt 4.
+ connect(this, TQT_SIGNAL(activated()), recipient, m_slot);
emit(activated());
- disconnect(this, SIGNAL(activated()), recipient, m_slot);
+ disconnect(this, TQT_SIGNAL(activated()), recipient, m_slot);
}
private:
- QCString m_slot;
+ TQCString m_slot;
PlaylistRecipientMap m_playlistRecipient;
};
@@ -108,7 +108,7 @@ KAction *K3bExporter::action()
"export_to_k3b",
i18n("Add Selected Items to Audio or Data CD"),
SmallIconSet("k3b"),
- SLOT(slotExport())
+ TQT_SLOT(slotExport())
);
m_action->setShortcutConfigurable(false);
@@ -129,8 +129,8 @@ void K3bExporter::exportPlaylistItems(const PlaylistItemList &items)
return;
DCOPClient *client = DCOPClient::mainClient();
- QCString appId, appObj;
- QByteArray data;
+ TQCString appId, appObj;
+ TQByteArray data;
if(!client->findObject("k3b-*", "K3bInterface", "", data, appId, appObj))
exportViaCmdLine(items);
@@ -149,7 +149,7 @@ void K3bExporter::slotExport()
void K3bExporter::exportViaCmdLine(const PlaylistItemList &items)
{
K3bOpenMode mode = openMode();
- QCString cmdOption;
+ TQCString cmdOption;
switch(mode) {
case AudioCD:
@@ -179,10 +179,10 @@ void K3bExporter::exportViaCmdLine(const PlaylistItemList &items)
void K3bExporter::exportViaDCOP(const PlaylistItemList &items, DCOPRef &ref)
{
- QValueList<DCOPRef> projectList;
+ TQValueList<DCOPRef> projectList;
DCOPReply projectListReply = ref.call("projects()");
- if(!projectListReply.get<QValueList<DCOPRef> >(projectList, "QValueList<DCOPRef>")) {
+ if(!projectListReply.get<TQValueList<DCOPRef> >(projectList, "TQValueList<DCOPRef>")) {
DCOPErrorMessage();
return;
}
@@ -213,7 +213,7 @@ void K3bExporter::DCOPErrorMessage()
bool K3bExporter::startNewK3bProject(DCOPRef &ref)
{
- QCString request;
+ TQCString request;
K3bOpenMode mode = openMode();
switch(mode) {
@@ -276,7 +276,7 @@ KAction *K3bPlaylistExporter::action()
SmallIconSet("k3b"),
0,
this,
- SLOT(slotExport()),
+ TQT_SLOT(slotExport()),
actions(),
"export_playlist_to_k3b"
);
@@ -59,13 +59,13 @@ class PlaylistAction : public KAction
/**
- * Defines a QObject to call (using the m_slot SLOT) when an action is
+ * Defines a TQObject to call (using the m_slot SLOT) when an action is
* emitted from a Playlist.
*/